@@ -113,8 +113,8 @@ class ModelRepository:
         try:
             conn = self.conpool.getconn()
             cur = conn.cursor()
-            cur.execute("INSERT INTO io_fintix.custom_model (filename, model) VALUES(%s, %s)",
-                        (model_name, psycopg2.Binary(python_script_content)))
+            cur.execute("INSERT INTO io_fintix.custom_model (model_uid, model_name, model) VALUES(%s, %s, %s)",
+                        (model_name, model_name, psycopg2.Binary(python_script_content)))
             conn.commit()
         except Exception as e:
             return (
